@@ -141,7 +141,7 @@ Postchunk::read(string const &transferfile, string const &datafile)
   readPostchunk(transferfile);
   
   // datafile
-  FILE *in = fopen(datafile.c_str(), "r");
+  FILE *in = fopen(datafile.c_str(), "rb");
   if(!in)
   {
     cerr << "Error: Could not open file '" << datafile << "'." << endl;
@@ -307,7 +307,7 @@ Postchunk::evalString(xmlNode *element)
   }
   else if(!xmlStrcmp(element->name, (const xmlChar *) "lit"))
   {
-    evalStringCache[element] = TransferInstr(ti_lit, XMLParseUtil::latin1(element->properties->children->content), 0);
+    evalStringCache[element] = TransferInstr(ti_lit, string((char *) element->properties->children->content), 0);
   }
   else if(!xmlStrcmp(element->name, (const xmlChar *) "b"))
   {
@@ -622,7 +622,7 @@ Postchunk::processCallMacro(xmlNode *localroot)
   InterchunkWord **myword = NULL;
   if(npar > 0)
   {
-    myword = new InterchunkWord *[npar];  
+    myword = new InterchunkWord *[npar+1];  
   }
   string **myblank = NULL;
   if(npar > 1)
@@ -630,14 +630,16 @@ Postchunk::processCallMacro(xmlNode *localroot)
     myblank = new string *[npar - 1];
   }
 
-  int idx = 0;
+  myword[0] = word[0];
+  
+  int idx = 1;
   for(xmlNode *i = localroot->children; i != NULL; i = i->next)
   {
     if(i->type == XML_ELEMENT_NODE)
     {
-      int pos = atoi((const char *) i->properties->children->content)-1;
+      int pos = atoi((const char *) i->properties->children->content);
       myword[idx] = word[pos];
-      if(idx-1 >= 0)
+      if(idx > 1)
       {
         myblank[idx-1] = blank[pos-1];
       }
@@ -1628,7 +1630,7 @@ Postchunk::unchunk(wstring const &chunk, FILE *output)
           }
           else if(uppercase_first)
           {
-	    if(iswalpha(chunk[i]))
+	    if(iswalnum(chunk[i]))
 	    {
 	      fputwc_unlocked(towupper(chunk[i]), output);
 	      uppercase_first = false;
@@ -1745,7 +1747,7 @@ Postchunk::splitWordsAndBlanks(wstring const &chunk, vector<wstring *> &words,
           }
           else if(uppercase_first)
           {
-	    if(iswalpha(chunk[i]))
+	    if(iswalnum(chunk[i]))
 	    {
 	      ref += towupper(chunk[i]);
 	      uppercase_first = false;
