@@ -139,7 +139,7 @@ Transfer::readData(FILE *in)
 void
 Transfer::readBil(string const &fstfile)
 {
-  FILE *in = fopen(fstfile.c_str(), "r");
+  FILE *in = fopen(fstfile.c_str(), "rb");
   if(!in)
   {
     cerr << "Error: Could not open file '" << fstfile << "'." << endl;
@@ -157,7 +157,7 @@ Transfer::read(string const &transferfile, string const &datafile,
   readTransfer(transferfile);
   
   // datafile
-  FILE *in = fopen(datafile.c_str(), "r");
+  FILE *in = fopen(datafile.c_str(), "rb");
   if(!in)
   {
     cerr << "Error: Could not open file '" << datafile << "'." << endl;
@@ -1427,7 +1427,9 @@ Transfer::copycase(string const &source_word, string const &target_word)
 
   if(!uppercase || (sizeone && uppercase))
   {
-    result = StringUtils::tolower(t_word);
+    result = t_word;
+    result[0] = towlower(result[0]);
+    //result = StringUtils::tolower(t_word);
   }
   else
   {
